Documentation
¶
Overview ¶
Package pool implements a pool of net.Conn interfaces to manage and reuse them.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // ErrClosed is the error resulting if the pool is closed via pool.Close(). ErrClosed = errors.New("pool is closed") )
Functions ¶
This section is empty.
Types ¶
type Conn ¶
type Conn struct {
Client io.Closer
Checker func(io.Closer) bool
// contains filtered or unexported fields
}
Conn is a wrapper around io.Closer
func (*Conn) MarkUnusable ¶
func (c *Conn) MarkUnusable()
MarkUnusable () marks the connection not usable any more, to let the pool close it instead of returning it to pool.
type IPool ¶
type IPool interface {
// Get returns a new connection from the pool. Closing the connections puts
// it back to the Pool. Closing it when the pool is destroyed or full will
// be counted as an error.
Get() (*Conn, error)
// Close closes the pool and all its connections. After Close() the pool is
// no longer usable.
Close() error
// Len returns the current number of connections of the pool.
Len() int
}
Ipool interface describes a pool implementation. A pool should have maximum capacity. An ideal pool is threadsafe and easy to use.
func NewPool ¶
NewPool returns a new pool based on buffered channels with an initial capacity and maximum capacity. Factory is used when initial capacity is greater than zero to fill the pool. A zero initialCap doesn't fill the Pool until a new Get() is called. During a Get(), If there is no new connection available in the pool, a new connection will be created via the Factory() method.
type Pool ¶
type Pool struct {
// contains filtered or unexported fields
}
Pool implements the Pool interface based on buffered channels.